@@ -20,24 +20,31 @@ from botocore.client import BaseClient, ClientMeta
 from .literals import AllowMessagesType, AppInstanceUserEndpointTypeType
 from .type_defs import (
     AppInstanceRetentionSettingsTypeDef,
+    ConfigurationTypeDef,
     CreateAppInstanceAdminResponseTypeDef,
+    CreateAppInstanceBotResponseTypeDef,
     CreateAppInstanceResponseTypeDef,
     CreateAppInstanceUserResponseTypeDef,
     DescribeAppInstanceAdminResponseTypeDef,
+    DescribeAppInstanceBotResponseTypeDef,
     DescribeAppInstanceResponseTypeDef,
     DescribeAppInstanceUserEndpointResponseTypeDef,
     DescribeAppInstanceUserResponseTypeDef,
     EmptyResponseMetadataTypeDef,
     EndpointAttributesTypeDef,
+    ExpirationSettingsTypeDef,
     GetAppInstanceRetentionSettingsResponseTypeDef,
     ListAppInstanceAdminsResponseTypeDef,
+    ListAppInstanceBotsResponseTypeDef,
     ListAppInstancesResponseTypeDef,
     ListAppInstanceUserEndpointsResponseTypeDef,
     ListAppInstanceUsersResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
     PutAppInstanceRetentionSettingsResponseTypeDef,
+    PutAppInstanceUserExpirationSettingsResponseTypeDef,
     RegisterAppInstanceUserEndpointResponseTypeDef,
     TagTypeDef,
+    UpdateAppInstanceBotResponseTypeDef,
     UpdateAppInstanceResponseTypeDef,
     UpdateAppInstanceUserEndpointResponseTypeDef,
     UpdateAppInstanceUserResponseTypeDef,
@@ -59,6 +66,7 @@ class Exceptions:
     ClientError: Type[BotocoreClientError]
     ConflictException: Type[BotocoreClientError]
     ForbiddenException: Type[BotocoreClientError]
+    NotFoundException: Type[BotocoreClientError]
     ResourceLimitExceededException: Type[BotocoreClientError]
     ServiceFailureException: Type[BotocoreClientError]
     ServiceUnavailableException: Type[BotocoreClientError]
@@ -118,12 +126,29 @@ class ChimeSDKIdentityClient(BaseClient):
         self, *, AppInstanceAdminArn: str, AppInstanceArn: str
     ) -> CreateAppInstanceAdminResponseTypeDef:
         """
-        Promotes an `AppInstanceUser` to an `AppInstanceAdmin`.
+        Promotes an `AppInstanceUser` or `AppInstanceBot` to an `AppInstanceAdmin`.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.create_app_instance_admin)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#create_app_instance_admin)
         """
 
+    def create_app_instance_bot(
+        self,
+        *,
+        AppInstanceArn: str,
+        ClientRequestToken: str,
+        Configuration: ConfigurationTypeDef,
+        Name: str = ...,
+        Metadata: str = ...,
+        Tags: Sequence[TagTypeDef] = ...
+    ) -> CreateAppInstanceBotResponseTypeDef:
+        """
+        Creates a bot under an Amazon Chime `AppInstance`.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.create_app_instance_bot)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#create_app_instance_bot)
+        """
+
     def create_app_instance_user(
         self,
         *,
@@ -132,7 +157,8 @@ class ChimeSDKIdentityClient(BaseClient):
         Name: str,
         ClientRequestToken: str,
         Metadata: str = ...,
-        Tags: Sequence[TagTypeDef] = ...
+        Tags: Sequence[TagTypeDef] = ...,
+        ExpirationSettings: ExpirationSettingsTypeDef = ...
     ) -> CreateAppInstanceUserResponseTypeDef:
         """
         Creates a user under an Amazon Chime `AppInstance`.
@@ -153,15 +179,23 @@ class ChimeSDKIdentityClient(BaseClient):
         self, *, AppInstanceAdminArn: str, AppInstanceArn: str
     ) -> EmptyResponseMetadataTypeDef:
         """
-        Demotes an `AppInstanceAdmin` to an `AppInstanceUser`.
+        Demotes an `AppInstanceAdmin` to an `AppInstanceUser` or `AppInstanceBot`.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.delete_app_instance_admin)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#delete_app_instance_admin)
         """
 
+    def delete_app_instance_bot(self, *, AppInstanceBotArn: str) -> EmptyResponseMetadataTypeDef:
+        """
+        Deletes an `AppInstanceBot`.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.delete_app_instance_bot)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#delete_app_instance_bot)
+        """
+
     def delete_app_instance_user(self, *, AppInstanceUserArn: str) -> EmptyResponseMetadataTypeDef:
         """
-        Deletes an `AppInstanceUser` .
+        Deletes an `AppInstanceUser`.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.delete_app_instance_user)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#delete_app_instance_user)
@@ -171,7 +205,7 @@ class ChimeSDKIdentityClient(BaseClient):
         self, *, AppInstanceUserArn: str, EndpointId: str
     ) -> EmptyResponseMetadataTypeDef:
         """
-        Deregisters an `AppInstanceUserEndpoint` .
+        Deregisters an `AppInstanceUserEndpoint`.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.deregister_app_instance_user_endpoint)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#deregister_app_instance_user_endpoint)
@@ -179,7 +213,7 @@ class ChimeSDKIdentityClient(BaseClient):
 
     def describe_app_instance(self, *, AppInstanceArn: str) -> DescribeAppInstanceResponseTypeDef:
         """
-        Returns the full details of an `AppInstance` .
+        Returns the full details of an `AppInstance`.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.describe_app_instance)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#describe_app_instance)
@@ -189,17 +223,27 @@ class ChimeSDKIdentityClient(BaseClient):
         self, *, AppInstanceAdminArn: str, AppInstanceArn: str
     ) -> DescribeAppInstanceAdminResponseTypeDef:
         """
-        Returns the full details of an `AppInstanceAdmin` .
+        Returns the full details of an `AppInstanceAdmin`.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.describe_app_instance_admin)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#describe_app_instance_admin)
         """
 
+    def describe_app_instance_bot(
+        self, *, AppInstanceBotArn: str
+    ) -> DescribeAppInstanceBotResponseTypeDef:
+        """
+        The `AppInstanceBot's` information.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.describe_app_instance_bot)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#describe_app_instance_bot)
+        """
+
     def describe_app_instance_user(
         self, *, AppInstanceUserArn: str
     ) -> DescribeAppInstanceUserResponseTypeDef:
         """
-        Returns the full details of an `AppInstanceUser` .
+        Returns the full details of an `AppInstanceUser`.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.describe_app_instance_user)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#describe_app_instance_user)
@@ -209,7 +253,7 @@ class ChimeSDKIdentityClient(BaseClient):
         self, *, AppInstanceUserArn: str, EndpointId: str
     ) -> DescribeAppInstanceUserEndpointResponseTypeDef:
         """
-        Returns the full details of an `AppInstanceUserEndpoint` .
+        Returns the full details of an `AppInstanceUserEndpoint`.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.describe_app_instance_user_endpoint)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#describe_app_instance_user_endpoint)
@@ -233,7 +277,7 @@ class ChimeSDKIdentityClient(BaseClient):
         self, *, AppInstanceArn: str
     ) -> GetAppInstanceRetentionSettingsResponseTypeDef:
         """
-        Gets the retention settings for an `AppInstance` .
+        Gets the retention settings for an `AppInstance`.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.get_app_instance_retention_settings)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#get_app_instance_retention_settings)
@@ -243,18 +287,28 @@ class ChimeSDKIdentityClient(BaseClient):
         self, *, AppInstanceArn: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListAppInstanceAdminsResponseTypeDef:
         """
-        Returns a list of the administrators in the `AppInstance` .
+        Returns a list of the administrators in the `AppInstance`.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_app_instance_admins)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#list_app_instance_admins)
         """
 
+    def list_app_instance_bots(
+        self, *, AppInstanceArn: str, MaxResults: int = ..., NextToken: str = ...
+    ) -> ListAppInstanceBotsResponseTypeDef:
+        """
+        Lists all `AppInstanceBots` created under a single `AppInstance`.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_app_instance_bots)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#list_app_instance_bots)
+        """
+
     def list_app_instance_user_endpoints(
         self, *, AppInstanceUserArn: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListAppInstanceUserEndpointsResponseTypeDef:
         """
         Lists all the `AppInstanceUserEndpoints` created under a single
-        `AppInstanceUser` .
+        `AppInstanceUser`.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_app_instance_user_endpoints)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#list_app_instance_user_endpoints)
@@ -264,7 +318,7 @@ class ChimeSDKIdentityClient(BaseClient):
         self, *, AppInstanceArn: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListAppInstanceUsersResponseTypeDef:
         """
-        List all `AppInstanceUsers` created under a single `AppInstance` .
+        List all `AppInstanceUsers` created under a single `AppInstance`.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_app_instance_users)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#list_app_instance_users)
@@ -274,7 +328,7 @@ class ChimeSDKIdentityClient(BaseClient):
         self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListAppInstancesResponseTypeDef:
         """
-        Lists all Amazon Chime `AppInstance` s created under a single AWS account.
+        Lists all Amazon Chime `AppInstance`s created under a single AWS account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.list_app_instances)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#list_app_instances)
@@ -301,6 +355,16 @@ class ChimeSDKIdentityClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#put_app_instance_retention_settings)
         """
 
+    def put_app_instance_user_expiration_settings(
+        self, *, AppInstanceUserArn: str, ExpirationSettings: ExpirationSettingsTypeDef = ...
+    ) -> PutAppInstanceUserExpirationSettingsResponseTypeDef:
+        """
+        Sets the number of days before the `AppInstanceUser` is automatically deleted.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.put_app_instance_user_expiration_settings)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#put_app_instance_user_expiration_settings)
+        """
+
     def register_app_instance_user_endpoint(
         self,
         *,
@@ -350,6 +414,16 @@ class ChimeSDKIdentityClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#update_app_instance)
         """
 
+    def update_app_instance_bot(
+        self, *, AppInstanceBotArn: str, Name: str, Metadata: str
+    ) -> UpdateAppInstanceBotResponseTypeDef:
+        """
+        Updates the name and metadata of an `AppInstanceBot`.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity.Client.update_app_instance_bot)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#update_app_instance_bot)
+        """
+
     def update_app_instance_user(
         self, *, AppInstanceUserArn: str, Name: str, Metadata: str
     ) -> UpdateAppInstanceUserResponseTypeDef:
