@@ -22,6 +22,10 @@ from .literals import (
     EndpointStatusType,
 )
 
+if sys.version_info >= (3, 9):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
@@ -30,31 +34,37 @@ else:
 
 __all__ = (
     "IdentityTypeDef",
+    "AppInstanceBotSummaryTypeDef",
     "ChannelRetentionSettingsTypeDef",
     "AppInstanceSummaryTypeDef",
     "AppInstanceTypeDef",
     "EndpointStateTypeDef",
     "EndpointAttributesTypeDef",
     "AppInstanceUserSummaryTypeDef",
-    "AppInstanceUserTypeDef",
+    "ExpirationSettingsTypeDef",
+    "LexConfigurationTypeDef",
     "CreateAppInstanceAdminRequestRequestTypeDef",
     "ResponseMetadataTypeDef",
     "TagTypeDef",
     "DeleteAppInstanceAdminRequestRequestTypeDef",
+    "DeleteAppInstanceBotRequestRequestTypeDef",
     "DeleteAppInstanceRequestRequestTypeDef",
     "DeleteAppInstanceUserRequestRequestTypeDef",
     "DeregisterAppInstanceUserEndpointRequestRequestTypeDef",
     "DescribeAppInstanceAdminRequestRequestTypeDef",
+    "DescribeAppInstanceBotRequestRequestTypeDef",
     "DescribeAppInstanceRequestRequestTypeDef",
     "DescribeAppInstanceUserEndpointRequestRequestTypeDef",
     "DescribeAppInstanceUserRequestRequestTypeDef",
     "GetAppInstanceRetentionSettingsRequestRequestTypeDef",
     "ListAppInstanceAdminsRequestRequestTypeDef",
+    "ListAppInstanceBotsRequestRequestTypeDef",
     "ListAppInstanceUserEndpointsRequestRequestTypeDef",
     "ListAppInstanceUsersRequestRequestTypeDef",
     "ListAppInstancesRequestRequestTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
+    "UpdateAppInstanceBotRequestRequestTypeDef",
     "UpdateAppInstanceRequestRequestTypeDef",
     "UpdateAppInstanceUserEndpointRequestRequestTypeDef",
     "UpdateAppInstanceUserRequestRequestTypeDef",
@@ -64,15 +74,21 @@ __all__ = (
     "AppInstanceUserEndpointSummaryTypeDef",
     "AppInstanceUserEndpointTypeDef",
     "RegisterAppInstanceUserEndpointRequestRequestTypeDef",
+    "AppInstanceUserTypeDef",
+    "PutAppInstanceUserExpirationSettingsRequestRequestTypeDef",
+    "ConfigurationTypeDef",
     "CreateAppInstanceAdminResponseTypeDef",
+    "CreateAppInstanceBotResponseTypeDef",
     "CreateAppInstanceResponseTypeDef",
     "CreateAppInstanceUserResponseTypeDef",
     "DescribeAppInstanceResponseTypeDef",
-    "DescribeAppInstanceUserResponseTypeDef",
     "EmptyResponseMetadataTypeDef",
+    "ListAppInstanceBotsResponseTypeDef",
     "ListAppInstanceUsersResponseTypeDef",
     "ListAppInstancesResponseTypeDef",
+    "PutAppInstanceUserExpirationSettingsResponseTypeDef",
     "RegisterAppInstanceUserEndpointResponseTypeDef",
+    "UpdateAppInstanceBotResponseTypeDef",
     "UpdateAppInstanceResponseTypeDef",
     "UpdateAppInstanceUserEndpointResponseTypeDef",
     "UpdateAppInstanceUserResponseTypeDef",
@@ -87,6 +103,10 @@ __all__ = (
     "PutAppInstanceRetentionSettingsResponseTypeDef",
     "ListAppInstanceUserEndpointsResponseTypeDef",
     "DescribeAppInstanceUserEndpointResponseTypeDef",
+    "DescribeAppInstanceUserResponseTypeDef",
+    "AppInstanceBotTypeDef",
+    "CreateAppInstanceBotRequestRequestTypeDef",
+    "DescribeAppInstanceBotResponseTypeDef",
 )
 
 IdentityTypeDef = TypedDict(
@@ -98,6 +118,16 @@ IdentityTypeDef = TypedDict(
     total=False,
 )
 
+AppInstanceBotSummaryTypeDef = TypedDict(
+    "AppInstanceBotSummaryTypeDef",
+    {
+        "AppInstanceBotArn": str,
+        "Name": str,
+        "Metadata": str,
+    },
+    total=False,
+)
+
 ChannelRetentionSettingsTypeDef = TypedDict(
     "ChannelRetentionSettingsTypeDef",
     {
@@ -178,18 +208,35 @@ AppInstanceUserSummaryTypeDef = TypedDict(
     total=False,
 )
 
-AppInstanceUserTypeDef = TypedDict(
-    "AppInstanceUserTypeDef",
+ExpirationSettingsTypeDef = TypedDict(
+    "ExpirationSettingsTypeDef",
     {
-        "AppInstanceUserArn": str,
-        "Name": str,
-        "Metadata": str,
-        "CreatedTimestamp": datetime,
-        "LastUpdatedTimestamp": datetime,
+        "ExpirationDays": int,
+        "ExpirationCriterion": Literal["CREATED_TIMESTAMP"],
+    },
+)
+
+_RequiredLexConfigurationTypeDef = TypedDict(
+    "_RequiredLexConfigurationTypeDef",
+    {
+        "RespondsTo": Literal["STANDARD_MESSAGES"],
+        "LexBotAliasArn": str,
+        "LocaleId": str,
+    },
+)
+_OptionalLexConfigurationTypeDef = TypedDict(
+    "_OptionalLexConfigurationTypeDef",
+    {
+        "WelcomeIntent": str,
     },
     total=False,
 )
 
+
+class LexConfigurationTypeDef(_RequiredLexConfigurationTypeDef, _OptionalLexConfigurationTypeDef):
+    pass
+
+
 CreateAppInstanceAdminRequestRequestTypeDef = TypedDict(
     "CreateAppInstanceAdminRequestRequestTypeDef",
     {
@@ -225,6 +272,13 @@ DeleteAppInstanceAdminRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteAppInstanceBotRequestRequestTypeDef = TypedDict(
+    "DeleteAppInstanceBotRequestRequestTypeDef",
+    {
+        "AppInstanceBotArn": str,
+    },
+)
+
 DeleteAppInstanceRequestRequestTypeDef = TypedDict(
     "DeleteAppInstanceRequestRequestTypeDef",
     {
@@ -255,6 +309,13 @@ DescribeAppInstanceAdminRequestRequestTypeDef = TypedDict(
     },
 )
 
+DescribeAppInstanceBotRequestRequestTypeDef = TypedDict(
+    "DescribeAppInstanceBotRequestRequestTypeDef",
+    {
+        "AppInstanceBotArn": str,
+    },
+)
+
 DescribeAppInstanceRequestRequestTypeDef = TypedDict(
     "DescribeAppInstanceRequestRequestTypeDef",
     {
@@ -307,6 +368,29 @@ class ListAppInstanceAdminsRequestRequestTypeDef(
     pass
 
 
+_RequiredListAppInstanceBotsRequestRequestTypeDef = TypedDict(
+    "_RequiredListAppInstanceBotsRequestRequestTypeDef",
+    {
+        "AppInstanceArn": str,
+    },
+)
+_OptionalListAppInstanceBotsRequestRequestTypeDef = TypedDict(
+    "_OptionalListAppInstanceBotsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListAppInstanceBotsRequestRequestTypeDef(
+    _RequiredListAppInstanceBotsRequestRequestTypeDef,
+    _OptionalListAppInstanceBotsRequestRequestTypeDef,
+):
+    pass
+
+
 _RequiredListAppInstanceUserEndpointsRequestRequestTypeDef = TypedDict(
     "_RequiredListAppInstanceUserEndpointsRequestRequestTypeDef",
     {
@@ -377,6 +461,15 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+UpdateAppInstanceBotRequestRequestTypeDef = TypedDict(
+    "UpdateAppInstanceBotRequestRequestTypeDef",
+    {
+        "AppInstanceBotArn": str,
+        "Name": str,
+        "Metadata": str,
+    },
+)
+
 UpdateAppInstanceRequestRequestTypeDef = TypedDict(
     "UpdateAppInstanceRequestRequestTypeDef",
     {
@@ -502,6 +595,48 @@ class RegisterAppInstanceUserEndpointRequestRequestTypeDef(
     pass
 
 
+AppInstanceUserTypeDef = TypedDict(
+    "AppInstanceUserTypeDef",
+    {
+        "AppInstanceUserArn": str,
+        "Name": str,
+        "Metadata": str,
+        "CreatedTimestamp": datetime,
+        "LastUpdatedTimestamp": datetime,
+        "ExpirationSettings": ExpirationSettingsTypeDef,
+    },
+    total=False,
+)
+
+_RequiredPutAppInstanceUserExpirationSettingsRequestRequestTypeDef = TypedDict(
+    "_RequiredPutAppInstanceUserExpirationSettingsRequestRequestTypeDef",
+    {
+        "AppInstanceUserArn": str,
+    },
+)
+_OptionalPutAppInstanceUserExpirationSettingsRequestRequestTypeDef = TypedDict(
+    "_OptionalPutAppInstanceUserExpirationSettingsRequestRequestTypeDef",
+    {
+        "ExpirationSettings": ExpirationSettingsTypeDef,
+    },
+    total=False,
+)
+
+
+class PutAppInstanceUserExpirationSettingsRequestRequestTypeDef(
+    _RequiredPutAppInstanceUserExpirationSettingsRequestRequestTypeDef,
+    _OptionalPutAppInstanceUserExpirationSettingsRequestRequestTypeDef,
+):
+    pass
+
+
+ConfigurationTypeDef = TypedDict(
+    "ConfigurationTypeDef",
+    {
+        "Lex": LexConfigurationTypeDef,
+    },
+)
+
 CreateAppInstanceAdminResponseTypeDef = TypedDict(
     "CreateAppInstanceAdminResponseTypeDef",
     {
@@ -511,6 +646,14 @@ CreateAppInstanceAdminResponseTypeDef = TypedDict(
     },
 )
 
+CreateAppInstanceBotResponseTypeDef = TypedDict(
+    "CreateAppInstanceBotResponseTypeDef",
+    {
+        "AppInstanceBotArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 CreateAppInstanceResponseTypeDef = TypedDict(
     "CreateAppInstanceResponseTypeDef",
     {
@@ -535,17 +678,19 @@ DescribeAppInstanceResponseTypeDef = TypedDict(
     },
 )
 
-DescribeAppInstanceUserResponseTypeDef = TypedDict(
-    "DescribeAppInstanceUserResponseTypeDef",
+EmptyResponseMetadataTypeDef = TypedDict(
+    "EmptyResponseMetadataTypeDef",
     {
-        "AppInstanceUser": AppInstanceUserTypeDef,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
-EmptyResponseMetadataTypeDef = TypedDict(
-    "EmptyResponseMetadataTypeDef",
+ListAppInstanceBotsResponseTypeDef = TypedDict(
+    "ListAppInstanceBotsResponseTypeDef",
     {
+        "AppInstanceArn": str,
+        "AppInstanceBots": List[AppInstanceBotSummaryTypeDef],
+        "NextToken": str,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
@@ -569,6 +714,15 @@ ListAppInstancesResponseTypeDef = TypedDict(
     },
 )
 
+PutAppInstanceUserExpirationSettingsResponseTypeDef = TypedDict(
+    "PutAppInstanceUserExpirationSettingsResponseTypeDef",
+    {
+        "AppInstanceUserArn": str,
+        "ExpirationSettings": ExpirationSettingsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 RegisterAppInstanceUserEndpointResponseTypeDef = TypedDict(
     "RegisterAppInstanceUserEndpointResponseTypeDef",
     {
@@ -578,6 +732,14 @@ RegisterAppInstanceUserEndpointResponseTypeDef = TypedDict(
     },
 )
 
+UpdateAppInstanceBotResponseTypeDef = TypedDict(
+    "UpdateAppInstanceBotResponseTypeDef",
+    {
+        "AppInstanceBotArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 UpdateAppInstanceResponseTypeDef = TypedDict(
     "UpdateAppInstanceResponseTypeDef",
     {
@@ -640,6 +802,7 @@ _OptionalCreateAppInstanceUserRequestRequestTypeDef = TypedDict(
     {
         "Metadata": str,
         "Tags": Sequence[TagTypeDef],
+        "ExpirationSettings": ExpirationSettingsTypeDef,
     },
     total=False,
 )
@@ -728,3 +891,58 @@ DescribeAppInstanceUserEndpointResponseTypeDef = TypedDict(
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
+
+DescribeAppInstanceUserResponseTypeDef = TypedDict(
+    "DescribeAppInstanceUserResponseTypeDef",
+    {
+        "AppInstanceUser": AppInstanceUserTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+AppInstanceBotTypeDef = TypedDict(
+    "AppInstanceBotTypeDef",
+    {
+        "AppInstanceBotArn": str,
+        "Name": str,
+        "Configuration": ConfigurationTypeDef,
+        "CreatedTimestamp": datetime,
+        "LastUpdatedTimestamp": datetime,
+        "Metadata": str,
+    },
+    total=False,
+)
+
+_RequiredCreateAppInstanceBotRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateAppInstanceBotRequestRequestTypeDef",
+    {
+        "AppInstanceArn": str,
+        "ClientRequestToken": str,
+        "Configuration": ConfigurationTypeDef,
+    },
+)
+_OptionalCreateAppInstanceBotRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateAppInstanceBotRequestRequestTypeDef",
+    {
+        "Name": str,
+        "Metadata": str,
+        "Tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateAppInstanceBotRequestRequestTypeDef(
+    _RequiredCreateAppInstanceBotRequestRequestTypeDef,
+    _OptionalCreateAppInstanceBotRequestRequestTypeDef,
+):
+    pass
+
+
+DescribeAppInstanceBotResponseTypeDef = TypedDict(
+    "DescribeAppInstanceBotResponseTypeDef",
+    {
+        "AppInstanceBot": AppInstanceBotTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
